@@ -9,34 +9,41 @@ def toArray(filepath: str, shape: Optional[Tuple[int, int]] = None) -> np.ndarra
 
     Parameters
     ----------
-    filepath : str
+    filepath: str
         Path of the RAW or CSV file
-    shape : tuple
+    shape: tuple
         Shape of image array (row, col)
 
     Returns
     -------
-    arr16b : np.array, dtype = np.uint16
+    arr16b: np.array, dtype = np.uint16
         16-bit image array.
+    
+    Usage
+    ------
+    >>> arr1 = toArray('./yourraw.raw', (300, 800))
+    >>> arr2 = toArray('./yourcsv.csv')
     '''
+    
     def raw2arr(rawPath: str, shape: Tuple[int, int]) -> np.ndarray:
         '''
         read a raw file as a numpy array
 
         Parameters
         ----------
-        rawPath : str
+        rawPath: str
             Path of the RAW file
         shape : tuple
             Shape of image array (row, col)
 
         Returns
         -------
-        arr16b : np.array, dtype = np.uint16
+        arr16b: np.array, dtype = np.uint16
             16-bit image array.
         '''
         raw = np.fromfile(rawPath, dtype=np.uint8)
         arr16b = np.reshape((raw[0::2] *256 + raw[1::2]), shape)
+        print(arr16b)
         return arr16b
 
     def csv2arr(csv_path_in:str) -> np.ndarray:
@@ -45,43 +52,80 @@ def toArray(filepath: str, shape: Optional[Tuple[int, int]] = None) -> np.ndarra
 
         Parameters
         ----------
-        csv_path_in : str
+        csv_path_in: str
             Path of input CSV file
 
         Returns
         ----------
-        arr : np.ndarray
+        arr: np.ndarray
             the numpy array of the csv file
         '''
         pd_data = pd.read_csv(csv_path_in,header=None, index_col=None)
         arr = pd_data.values
         return arr
 
-    if filepath[-3:]== 'csv':
-        csv2arr(filepath)
-    elif filepath[-3:]== 'raw':
-        raw2arr(filepath, shape)
-
-
-
-
+    if filepath[-3:] == 'csv':
+        return csv2arr(filepath)
+    elif filepath[-3:] == 'raw':
+        return raw2arr(filepath, shape)
 
 def arr2csv(array: np.ndarray, csv_path_out: str) -> None:
     '''
-    output the csv file from a numpy array
+    output to the csv file from a numpy array
 
     Parameters
     ----------
-    array : array
+    array: array
         A numpy array
-    csv_path_out : str
+    csv_path_out: str
         Path of outuput CSV file
 
     Returns
     ----------
     None
+
+    Usage
+    ---------
+    >>> arr = np.array([1, 2, 3])
+    >>> arr2csv(arr, './yourcsv.csv')
     '''
     # Convert a np.array into pd.DataFrame
     df = pd.DataFrame(array)
     # Convert a pd.DataFrame into csv
-    df.to_csv(csv_path_out, header=False, index=False)
\ No newline at end of file
+    df.to_csv(csv_path_out, header=False, index=False)
+
+def createDVS(img1: np.ndarray, img2: np.ndarray, threshold: int, above_thresh_val: Optional[int] = None, below_thresh_val: Optional[int] = 0) -> np.ndarray:
+    '''
+    return a dvs img by calculating the difference between img1 and img2
+
+    Parameters
+    ----------
+    img1: np.ndarray
+        first image
+    img2: np.ndarray
+        secion image
+    threshold: int
+        the threshold of abs(img1-img2)
+
+    above_thresh_val: Optional[int] = None
+        if the value after abs(img1-img2) is bigger than threshold, then set it to above_thresh_val
+
+    Returns
+    ----------
+    dvs: np.ndarray
+
+    Usage
+    ----------
+    >>> arr1 = np.array([50, 50, 50]).astype(np.uint8)
+    >>> arr2 = np.array([10, 40, 90]).astype(np.uint8)
+    >>> ITB.create_dvs(arr1, arr2, 10)
+    [255   0 255]
+    '''
+
+    if not above_thresh_val:
+        above_thresh_val = np.iinfo(img1.dtype).max
+    dvs = np.where(img1>img2, img1-img2, img2-img1)
+
+    dvs[dvs > threshold] = above_thresh_val
+    dvs[threshold >= dvs] = below_thresh_val
+    return dvs
\ No newline at end of file
